<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive"
	xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
	xmlns:op="utc.fr:ics/opale3"
	exclude-result-prefixes="sc sp op">
	<xsl:import href="intern:bswsp:~param/libLaTeX/_common/latex.xsl"/>
	<xsl:import href="intern:bswsp:~param/libLaTeX/_common/labelRef.xsl"/> 
	
	<xsl:output method="text" encoding="UTF-8" indent="no"/>
	<xsl:param name="vDialog"/>
	<xsl:param name="vAgent"/>
	
	<xsl:variable name="config" select="getContent(gotoMeta(),'')" />
	
	<xsl:template match="op:txtRes">
		<xsl:if test="contains($config,'side')">
			\begin{figure}[ht!]
			<xsl:if test="contains($config,'lft')">
				\begin{minipage}{.5\linewidth}
				<xsl:apply-templates select="sp:img"/>
				\end{minipage}
				\begin{minipage}{.5\linewidth}
				<xsl:apply-templates select="sp:txt"/>
				\end{minipage}
			</xsl:if>
			<xsl:if test="contains($config,'rgt')">
				\begin{minipage}{.5\linewidth}
				<xsl:apply-templates select="sp:txt"/>
				\end{minipage}
				\begin{minipage}{.5\linewidth}
				<xsl:apply-templates select="sp:img"/>
				\end{minipage}
			</xsl:if>
			\end{figure}
		</xsl:if>
		
		<xsl:if test="contains($config,'float')">
			\begin{figwindow}[0,<xsl:if test="contains($config,'rgt')">r</xsl:if><xsl:if test="contains($config,'lft')">l</xsl:if>,<xsl:apply-templates select="sp:img" mode="float"/>]
			<xsl:apply-templates select="sp:txt"/>\end{figwindow}
		</xsl:if>
		
		<xsl:variable name="footnotes" select="getDialogVar('footnotes')" />
		<xsl:for-each select="$footnotes/footnote">
			<xsl:if test="position()=1 and count($footnotes/footnote) > 1">
				\addtocounter{footnote}{-<xsl:value-of select="count($footnotes/footnote) - 1"/>}
			</xsl:if>
			<xsl:if test="not(position()=1)">
				\addtocounter{footnote}{1}
			</xsl:if>
			\footnotetext{<xsl:value-of select="." disable-output-escaping="yes"/>}
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template match="sp:txt">
		<xsl:variable name="init"><init/></xsl:variable>
		<xsl:variable name="footnotes2" select="setDialogVar('footnotes',$init)"/>
		<xsl:value-of select="getContent(gotoSubModel(),'env')" disable-output-escaping="yes"/>\par
	</xsl:template>
	
	
	<xsl:template match="sp:img">
		\centering
		<xsl:variable name="size" select="getContent(gotoSubModel(),'props')"/>
		\SCincludeShortIllustratedTextGraphics{<xsl:if test="$size"><xsl:value-of select="$size"/></xsl:if>}{<xsl:value-of select="getUrl(gotoSubModel(),'')" disable-output-escaping="yes"/>}
		<xsl:value-of select="getContent(gotoSubModel(),'title')" disable-output-escaping="yes"/><xsl:call-template name="putResLabel" />
	</xsl:template>
	
	<xsl:template match="sp:img" mode="float"><!--
--><xsl:variable name="size" select="getContent(gotoSubModel(),'props')"/><!--
--><xsl:variable name="caption" select="getContent(gotoSubModel(),'title')" /><!--
-->\SCincludeLongIllustratedTextGraphics{<xsl:if test="$size"><xsl:value-of select="$size"/></xsl:if>}{<xsl:value-of select="getUrl(gotoSubModel(),'')" disable-output-escaping="yes"/>},<xsl:value-of select="normalize-space(substring-after($caption,'\caption'))" disable-output-escaping="yes"/><xsl:call-template name="putResLabel" /><!--
--></xsl:template>
	
	
	<!--ATTENTION ! quand on utilise xsl:import les templates définis dans l'import n'ont pas la priorité sur les templates locaux
		Conséquence si on a un <xsl:template match="*"/> en local il ne peut y avoir éxécutions des templates importés autres que ceux appelés
		par xsl;call-template
		Pour palier à celà il convient d'ajouter un <xsl;apply_imports/> dans le <xsl:template match="*"/>
	-->
	<xsl:template match="*"><xsl:apply-imports/></xsl:template>
</xsl:stylesheet>
