<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive"
	xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
	xmlns:op="utc.fr:ics/opale3"

	exclude-result-prefixes="sc sp op">
	<xsl:import href="intern:bswsp:~param/libLaTeX/_common/latex.xsl"/>

<xsl:output method="text" encoding="UTF-8" indent="no"/>
<xsl:param name="vDialog"/>
<xsl:param name="vAgent"/>

	<xsl:template match="op:amcRoot">
<!--		Génération des variables de publication-->
		<xsl:value-of select="getContent(gotoMeta(),'')" disable-output-escaping="yes"/>
		<xsl:apply-templates select="sp:amc" mode="meta"/>

\makeatletter\def\input@path{{skin/}}\makeatother
\documentclass[a4paper]{article}
	\usepackage[utf8]{inputenc}
	\usepackage[T1]{fontenc}
	\usepackage{lmodern}
	\usepackage{amsmath,amsfonts,amssymb}
	\usepackage{scamc}
	\usepackage{scunicode}
	\usepackage{caption}
	\usepackage{colortbl}
	\usepackage{stmaryrd}
	\usepackage{bbm}
	\usepackage{eurosym}
	\usepackage{listings}
	
	<!-- option pour la correction ou la feuille de réponses séparée -->
	<xsl:variable name="vOption1">
		<xsl:choose>
			<xsl:when test="getDialogVar('vContent') = 'solution'"><xsl:text>,correc</xsl:text></xsl:when>
			<xsl:when test="getDialogVar('vSeparate') = 1"><xsl:text>,ensemble</xsl:text></xsl:when>
		</xsl:choose>
	</xsl:variable>
	<!-- option ordre -->
	<xsl:variable name="vOption2">
		<xsl:if test="getDialogVar('vAnswerShuffle') = 0"><xsl:text>,ordre</xsl:text></xsl:if>
	</xsl:variable>
	<xsl:value-of select="concat('\usepackage[francais,bloc,outsidebox',$vOption1,$vOption2,']{automultiplechoice}')"/>
	\DeclareGraphicsExtensions{.pdf,.png,.jpg,.gif}

	<!-- définitions des données spécifiques pour l'entête -->
	%définitions des données spécifiques pour l'entête
	\title{<xsl:value-of select="getDialogVar('vTitle')"/>}
	\degree{<xsl:value-of select="getDialogVar('vDegree')"/>}
	\course{<xsl:value-of select="getDialogVar('vCourse')"/>}
  \schoolYear{<xsl:value-of select="getDialogVar('vSchoolYear')"/>}
  \date{<xsl:value-of select="getDialogVar('vDate')"/>}
  \duration{<xsl:value-of select="getDialogVar('vDuration')"/>}

\AMCsetFoot{\hfil Page \thepage{} / \AMCpageref{dernierepage}\hfil} 
\begin{document}

	<!-- barème -->
	<xsl:apply-templates select="sp:amc" mode="bareme"/>

	<!-- création des catégories -->
	<xsl:if test="getDialogVar('vCategories') = 1">
		<xsl:apply-templates select="sp:amc" />
	</xsl:if>

	% début commande exemplaire
	<xsl:choose>
		<xsl:when test="getDialogVar('vContent') = 'solution'">
	\exemplaire{1}{
		</xsl:when>
		<xsl:when test="getDialogVar('vContent') = 'test'">
	\exemplaire{<xsl:value-of select="getDialogVar('vCopies')"/>}{
		</xsl:when>
	</xsl:choose>
		\setcounter{figure}{0}
	    \setcounter{table}{0}
		\setcounter{equation}{0}
		\setcounter{footnote}{0} 
		%%% debut de l’en-tête des copies :
		\SCheader
    \begin{SCinstructions}
    	<xsl:apply-templates select="sp:amc" mode="instruct"/>

\begin{quote}
Le sujet comporte \AMCpageref{dernierepage} pages.
\end{quote}
\end{SCinstructions}
    <xsl:if test="getDialogVar('vSeparate') = 0">
    	\SCstudent{<xsl:value-of select="getDialogVar('vCode')"/>}
    </xsl:if>
    \newpage
		%%% fin de l’en-tête

		<xsl:choose>
			<xsl:when test="getDialogVar('vCategories') = 0">
		%%% début des questions %%%
			<xsl:apply-templates select="sp:amc" />
		%%% fin desquestions %%%
			</xsl:when>
			<xsl:when test="getDialogVar('vCategories') = 1">
		%%% début du mélange des catégories %%%
			<xsl:apply-templates select="sp:amc" mode="cat"/>
		%%% fin du mélange des catégories %%%
			</xsl:when>
		</xsl:choose>

		<!-- Si la feuille de réponse est séparée -->
		<xsl:if test="getDialogVar('vSeparate') = 1 and getDialogVar('vContent') != 'solution' ">
			<xsl:choose>
				<xsl:when test="getDialogVar('vPrint') = 'recto'">\clearpage</xsl:when>
				<xsl:when test="getDialogVar('vPrint') = 'verso'">\AMCcleardoublepage</xsl:when>
			</xsl:choose>
		\AMCdebutFormulaire

		\SCanswerSheetHeader{<xsl:value-of select="getDialogVar('vCode')"/>}
		%%% fin de l’en-tête de la feuille de réponses

		\formulaire
		</xsl:if>
		<!-- Fin feuille de réponse est séparée -->
		\clearpage

	} % fin commande exemplaire

\end{document}
	</xsl:template>

	<xsl:template match="sp:amc">
		<xsl:value-of select="getContent(gotoSubModel(),'')" disable-output-escaping="yes"/>
	</xsl:template>

	<xsl:template match="sp:amc" mode="meta">
		<xsl:value-of select="getContent(gotoSubModel(),'meta')" disable-output-escaping="yes"/>
	</xsl:template>

	<xsl:template match="sp:amc" mode="bareme">
		<xsl:value-of select="getContent(gotoSubModel(),'bareme')" disable-output-escaping="yes"/>
	</xsl:template>

	<xsl:template match="sp:amc" mode="cat">
		<xsl:value-of select="getContent(gotoSubModel(),'cat')" disable-output-escaping="yes"/>
	</xsl:template>

	<xsl:template match="sp:amc" mode="instruct">
		<xsl:value-of select="getContent(gotoSubModel(),'instruct')" disable-output-escaping="yes"/>
	</xsl:template>


  <!--ATTENTION ! quand on utilise xsl:import les templates définis dans l'import n'ont pas la priorité sur les templates locaux
		Conséquence si on a un <xsl:template match="*"/> en local il ne peut y avoir éxécutions des templates importés autres que ceux appelés
		par xsl;call-template
		Pour palier à celà il convient d'ajouter un <xsl;apply_imports/> dans le <xsl:template match="*"/>
	-->
  <xsl:template match="*"><xsl:apply-imports/></xsl:template>
  
</xsl:stylesheet>
