<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
	xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive"
	xmlns:op="utc.fr:ics/opale3"
  xmlns:msl="scpf.org:base"
  exclude-result-prefixes="sc sp op msl">
<xsl:output method="text" encoding="UTF-8" indent="no"/>
<xsl:param name="vDialog"/>
<xsl:param name="vAgent"/>

<xsl:template match="text()">
  <xsl:call-template name="escapeLaTeX">
    <xsl:with-param name="string" select="." />
  </xsl:call-template>
</xsl:template>

  <!--Utilisé pour permettre de metre à la ligne les bloc souhaités-->
  <xsl:variable name="newline">
    <xsl:text>
      
    </xsl:text>
  </xsl:variable>
  
<xsl:template match="text()" mode="env">
  <xsl:call-template name="escapeLaTeX">
    <xsl:with-param name="string" select="." />
  </xsl:call-template>
</xsl:template>

<!-- nettoyage des équations -->
<xsl:template name="cleanEquation">
  <xsl:param name="equation" />
  <!-- remplacement des espaces insécables et tabulations par un espace simple et des espaces fines insécables par une espace insécable LateX (~) -->
  <xsl:variable name="espace" select="translate($equation,'&#xa0;&#x9;&#8239;','  ~')" />
  <!-- suppression des sauts de ligne et retours chariot en fin d'équation -->
  <xsl:call-template name="cleanEnd">
    <xsl:with-param name="string" select="$espace"/>
  </xsl:call-template>
</xsl:template>

<xsl:template name="cleanEnd">
  <xsl:param name="string"/>
  <xsl:choose>
    <xsl:when test="substring($string, string-length($string)) = '&#xa;' or substring($string, string-length($string)) = '&#xd;' or substring($string, string-length($string)) = ' ' ">
      <xsl:call-template name="cleanEnd">
        <xsl:with-param name="string" select="substring($string,1,string-length($string)-1)"/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <xsl:copy-of select="$string"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- règles pour le texte -->
<xsl:template name="escapeLaTeX">
<xsl:param name="string" />
<!-- remplacement ou suppression de différents caractères "invisibles" : espace insécable, tabulation, nouvelle ligne, retour chariot -->
<xsl:variable name="espace" select="translate($string,'&#xa0;&#x9;&#xa;&#xd;','  ')" />
<xsl:choose>
  <xsl:when test="$espace = ' ' or (string-length($espace) > 0 and normalize-space($espace) = '')"><xsl:text> </xsl:text></xsl:when>
  <xsl:otherwise>
	  <xsl:variable name="backslash">
  		<xsl:call-template name="rechercher-remplacer">
  			<xsl:with-param name="chaine"><xsl:copy-of select="$espace"/></xsl:with-param>
  			<xsl:with-param name="cherche" select="'\'"/>
  			<xsl:with-param name="remplace" select="'\textbackslash'"/>
  		</xsl:call-template>
  	</xsl:variable>
  	<xsl:variable name="op_curly">
  		<xsl:call-template name="rechercher-remplacer">
  			<xsl:with-param name="chaine"><xsl:copy-of select="$backslash"/></xsl:with-param>
  			<xsl:with-param name="cherche" select="'{'"/>
  			<xsl:with-param name="remplace" select="'\{'"/>
  		</xsl:call-template>
  	</xsl:variable>
  	<xsl:variable name="cl_curly">
  		<xsl:call-template name="rechercher-remplacer">
  			<xsl:with-param name="chaine"><xsl:copy-of select="$op_curly"/></xsl:with-param>
  			<xsl:with-param name="cherche" select="'}'"/>
  			<xsl:with-param name="remplace" select="'\}'"/>
  		</xsl:call-template>
  	</xsl:variable>
  	<xsl:variable name="backslash2">
  		<xsl:call-template name="rechercher-remplacer">
  			<xsl:with-param name="chaine"><xsl:copy-of select="$cl_curly"/></xsl:with-param>
  			<xsl:with-param name="cherche" select="'\textbackslash'"/>
  			<xsl:with-param name="remplace" select="'\textbackslash{}'"/>
  		</xsl:call-template>
  	</xsl:variable>
  	<xsl:variable name="tilde">
  		<xsl:call-template name="rechercher-remplacer">
  			<xsl:with-param name="chaine"><xsl:copy-of select="$backslash2"/></xsl:with-param>
  			<xsl:with-param name="cherche" select="'~'"/>
  			<xsl:with-param name="remplace" select="'\textasciitilde{}'"/>
  		</xsl:call-template>
  	</xsl:variable>
    <xsl:variable name="nbsp">
      <xsl:call-template name="rechercher-remplacer">
        <xsl:with-param name="chaine"><xsl:copy-of select="$tilde"/></xsl:with-param>
        <xsl:with-param name="cherche" select="'&#8239;'"/>
        <xsl:with-param name="remplace" select="'~'"/>
      </xsl:call-template>
    </xsl:variable>
  	<xsl:variable name="sharp">
  		<xsl:call-template name="rechercher-remplacer">
  			<xsl:with-param name="chaine"><xsl:copy-of select="$nbsp"/></xsl:with-param>
  			<xsl:with-param name="cherche" select="'#'"/>
  			<xsl:with-param name="remplace" select="'\#'"/>
  		</xsl:call-template>
  	</xsl:variable>
  	<xsl:variable name="dollar">
  		<xsl:call-template name="rechercher-remplacer">
  			<xsl:with-param name="chaine" select="$sharp"/>
  			<xsl:with-param name="cherche" select="'$'"/>
  			<xsl:with-param name="remplace" select="'\$'"/>
  		</xsl:call-template>
  	</xsl:variable>
  	<xsl:variable name="percent">
  		<xsl:call-template name="rechercher-remplacer">
  			<xsl:with-param name="chaine" select="$dollar"/>
  			<xsl:with-param name="cherche" select="'%'"/>
  			<xsl:with-param name="remplace" select="'\%'"/>
  		</xsl:call-template>
  	</xsl:variable>
  	<xsl:variable name="circum">
  		<xsl:call-template name="rechercher-remplacer">
  			<xsl:with-param name="chaine" select="$percent"/>
  			<xsl:with-param name="cherche" select="'^'"/>
  			<xsl:with-param name="remplace" select="'\textasciicircum{}'"/>
  		</xsl:call-template>
  	</xsl:variable>
  	<xsl:variable name="underscore">
  		<xsl:call-template name="rechercher-remplacer">
  			<xsl:with-param name="chaine" select="$circum"/>
  			<xsl:with-param name="cherche" select="'_'"/>
  			<xsl:with-param name="remplace" select="'\_'"/>
  		</xsl:call-template>
  	</xsl:variable>
  	<xsl:variable name="ampersand">
  		<xsl:call-template name="rechercher-remplacer">
  			<xsl:with-param name="chaine" select="$underscore"/>
  			<xsl:with-param name="cherche" select="'&amp;'"/>
  			<xsl:with-param name="remplace" select="'\&amp;'"/>
  		</xsl:call-template>
  	</xsl:variable>
    <xsl:variable name="norm" select="normalize-space($ampersand)" />
    <xsl:variable name="firstCharacter" select="substring($norm,1,1)" />
    <xsl:variable name="lastCharacter" select="substring($norm,string-length($norm))" />
    <xsl:variable name="begin" select="substring-before($ampersand,$firstCharacter)" />
    <xsl:variable name="end">
      <xsl:call-template name="substring-after-last">
           <xsl:with-param name="input" select="$ampersand"/>
           <xsl:with-param name="substr" select="$lastCharacter"/>
      </xsl:call-template>
    </xsl:variable><!--
  --><xsl:if test="contains($begin,' ')"><xsl:text> </xsl:text></xsl:if><!--
  --><xsl:copy-of select="normalize-space($ampersand)" /><!--
  --><xsl:if test="contains($end,' ')"><xsl:text> </xsl:text></xsl:if><!--
--></xsl:otherwise>
</xsl:choose>
</xsl:template>


<!-- règle de chercher-remplacer -->
<xsl:template name="rechercher-remplacer">
	<!-- 3 paramètres : chaîne à traiter, le motif à chercher, et celui qui le remplacera -->
	<xsl:param name="chaine"/>
	<xsl:param name="cherche"/>
	<xsl:param name="remplace"/>
	<xsl:choose>
		<!-- si on a bien défini cherche et remplace et si la chaine contient bien le motif cherche, on copie ce qu'il y a avant puis le motif remplace et exécute récursivement cette règle sur la fin de chaine -->
		<xsl:when test="$cherche and $remplace and contains ($chaine,$cherche)">
			<xsl:value-of select="substring-before($chaine,$cherche)"/>
			<xsl:value-of select="$remplace"/>
			<xsl:call-template name="rechercher-remplacer">
				<xsl:with-param name="chaine" select="substring-after($chaine,$cherche)"/>
				<xsl:with-param name="cherche" select="$cherche"/>
				<xsl:with-param name="remplace" select="$remplace"/>
			</xsl:call-template>
		</xsl:when>
		<!-- sinon on se contente de copier le contenu de la chaine -->
		<xsl:otherwise>
			<xsl:value-of select="$chaine"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="substring-after-last">
<xsl:param name="input"/>
<xsl:param name="substr"/>
<!-- on récupère la chaîne après la première occurrence -->
<xsl:variable name="temp" select="substring-after($input,$substr)"/>
<xsl:choose>
  <!-- si celle-ci contient une occurrence, on recommence  -->
  <xsl:when test="$substr and contains($temp,$substr)">
    <xsl:call-template name="substring-after-last">
      <xsl:with-param name="input" select="$temp"/>
      <xsl:with-param name="substr" select="$substr"/>
    </xsl:call-template>
  </xsl:when>
  <xsl:otherwise>
    <xsl:value-of select="$temp"/>
  </xsl:otherwise>
</xsl:choose>
</xsl:template>


<!-- définition des intro/conclu -->
<xsl:template name="section">
	<xsl:param name="level"/>
	<xsl:param name="title"/>
  <xsl:if test="$level = 0">
    <xsl:value-of select="$newline"/>\chapter*{<xsl:value-of select="$title" disable-output-escaping="yes"/>}
  \addcontentsline{toc}{chapter}{\numberline{}<xsl:value-of select="$title" disable-output-escaping="yes"/>}
  </xsl:if>
  <xsl:if test="$level = 1">
    <xsl:value-of select="$newline"/>\section*{<xsl:value-of select="$title" disable-output-escaping="yes"/>}
  \addcontentsline{toc}{section}{\numberline{}<xsl:value-of select="$title" disable-output-escaping="yes"/>}
  </xsl:if>
  <xsl:if test="$level = 2">
    <xsl:value-of select="$newline"/>\subsection*{<xsl:value-of select="$title" disable-output-escaping="yes"/>}
  \addcontentsline{toc}{subsection}{\numberline{}<xsl:value-of select="$title" disable-output-escaping="yes"/>}
  </xsl:if>
  <xsl:if test="$level = 3">
    <xsl:value-of select="$newline"/>\subsubsection*{<xsl:value-of select="$title" disable-output-escaping="yes"/>}
  \addcontentsline{toc}{subsubsection}{\numberline{}<xsl:value-of select="$title" disable-output-escaping="yes"/>}
  </xsl:if>
  <xsl:if test="$level = 4">
    <xsl:value-of select="$newline"/>\paragraph*{<xsl:value-of select="$title" disable-output-escaping="yes"/>}
  </xsl:if>
  <xsl:if test="$level > 4">
    <xsl:value-of select="$newline"/>\subparagraph*{<xsl:value-of select="$title" disable-output-escaping="yes"/>}
  </xsl:if>
</xsl:template>


</xsl:stylesheet>